@@ -44,7 +44,7 @@ private Q_SLOTS:
     void testMoveRow();
     void testAppendRowToEmptyModel();
 
-    void testLoadLegacy();
+    void testResetConfig();
 
 private:
     MockRegistry *m_registry;
